@@ -20,7 +20,7 @@ def _navigation_entries(context, pages, section=None, is_json=False):
 
     def page_entry(page):
         # Do nothing if the page is to be hidden from not logged in users
-        if page.hide_from_anonymous and not request.user.is_authenticated():
+        if page.hide_from_anonymous and not request.user.is_authenticated:
             return
 
         url = page.get_absolute_url()
